@@ -1,19 +1,14 @@
 from __future__ import annotations
 
 from dataclasses import dataclass, field
-from enum import Enum, IntEnum
-from typing import Any, Callable, NamedTuple, Protocol, Union
+from typing import Callable, NamedTuple, Union
 
-import vapoursynth as vs
-from vsexprtools import expr_func, ComparatorFunc
-from vskernels import Catrom, Kernel, VideoProp
-from vskernels.kernels.abstract import Scaler
+from vsexprtools import expr_func
+from vskernels import Kernel
 from vsmask.edge import EdgeDetect
-
-from .utils import merge_clip_props
+from vstools import ComparatorFunc, CustomIntEnum, CustomStrEnum, VSMapValue, merge_clip_props, vs, Resolution
 
 __all__ = [
-    'GenericScaler',
     'CreditMaskT', 'Resolution', 'DescaleAttempt',
     'DescaleMode', 'DescaleResult', 'PlaneStatsKind',
     '_DescaleTypeGuards'
@@ -23,54 +18,6 @@ __all__ = [
 CreditMaskT = Union[vs.VideoNode, Callable[[vs.VideoNode, vs.VideoNode], vs.VideoNode], EdgeDetect]
 
 
-class _GeneriScaleNoShift(Protocol):
-    def __call__(self, clip: vs.VideoNode, width: int, height: int, *args: Any, **kwds: Any) -> vs.VideoNode:
-        ...
-
-
-class _GeneriScaleWithShift(Protocol):
-    def __call__(
-        self, clip: vs.VideoNode, width: int, height: int, shift: tuple[float, float],
-        *args: Any, **kwds: Any
-    ) -> vs.VideoNode:
-        ...
-
-
-class GenericScaler(Scaler):
-    kernel: Kernel = Catrom()
-
-    def __init__(
-        self, func: _GeneriScaleNoShift | _GeneriScaleWithShift | Callable[..., vs.VideoNode], **kwargs: Any
-    ) -> None:
-        self.func = func
-        self.kwargs = kwargs
-
-    def scale(self, clip: vs.VideoNode, width: int, height: int, shift: tuple[float, float] = (0, 0)) -> vs.VideoNode:
-        if shift != (0, 0):
-            try:
-                return self.func(clip, width, height, shift, **self.kwargs)
-            except BaseException:
-                try:
-                    return self.func(clip, width=width, height=height, shift=shift, **self.kwargs)
-                except BaseException:
-                    pass
-
-        try:
-            scaled = self.func(clip, width, height, **self.kwargs)
-        except BaseException:
-            scaled = self.func(clip, width=width, height=height, **self.kwargs)
-
-        return self.kernel.shift(scaled, shift)
-
-
-class Resolution(NamedTuple):
-    """Tuple representing a resolution."""
-
-    width: int
-
-    height: int
-
-
 class DescaleAttempt(NamedTuple):
     """Tuple representing a descale attempt."""
 
@@ -99,7 +46,7 @@ class DescaleAttempt(NamedTuple):
     @classmethod
     def from_args(
         cls, clip: vs.VideoNode, width: int, height: int, shift: tuple[float, float],
-        kernel: Kernel, mode: DescaleMode, **kwargs: VideoProp
+        kernel: Kernel, mode: DescaleMode, **kwargs: VSMapValue
     ) -> DescaleAttempt:
         descaled = kernel.descale(clip, width, height, shift)
         descaled = descaled.std.SetFrameProps(**kwargs)
@@ -145,7 +92,7 @@ class DescaleResult:
     out: vs.VideoNode
 
 
-class PlaneStatsKind(str, Enum):
+class PlaneStatsKind(CustomStrEnum):
     AVG = 'Average'
     MIN = 'Min'
     MAX = 'Max'
@@ -158,7 +105,7 @@ class DescaleModeMeta:
     op: ComparatorFunc = field(default_factory=lambda: max)
 
 
-class DescaleMode(DescaleModeMeta, IntEnum):
+class DescaleMode(DescaleModeMeta, CustomIntEnum):
     PlaneDiff = 0
     PlaneDiffMax = 1
     PlaneDiffMin = 2
